CatalogHipsLayer
================

.. currentmodule:: pywwt.layers

.. autoclass:: CatalogHipsLayer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CatalogHipsLayer.size_att
      ~CatalogHipsLayer.size_vmax
      ~CatalogHipsLayer.size_vmin

   .. rubric:: Methods Summary

   .. autosummary::

      ~CatalogHipsLayer.refresh
      ~CatalogHipsLayer.update_data

   .. rubric:: Attributes Documentation

   .. autoattribute:: size_att
   .. autoattribute:: size_vmax
   .. autoattribute:: size_vmin

   .. rubric:: Methods Documentation

   .. automethod:: refresh
   .. automethod:: update_data
